import { fetchAPI } from "@/lib/api";
import { Show } from "solid-js";
import { createContext, createResource, JSX } from "solid-js";

const DEFAULT_USER = {
	id: "",
	name: "Miguel da Mota",
	email: "miguel@damota.de",
	initials: "",
};

export const UserContext = createContext({
	user: DEFAULT_USER,
});

export function UserProvider(props: { children: JSX.Element }) {
	const [user] = createResource(getMe);

	return (
		<Show when={!user.loading} fallback={<p>Loading...</p>}>
			<UserContext.Provider value={{ user: user()! }}>
				{props.children}
			</UserContext.Provider>
		</Show>
	);
}

export function getInitials(name: string) {
	const [first, ...others] = name.split(" ");

	let initials = first[0];

	if (others.length > 0) {
		initials += others[0][0];
	}

	return initials.toUpperCase();
}

async function getMe(): Promise<typeof DEFAULT_USER> {
	const user = await fetchAPI<typeof DEFAULT_USER>("/me");

	user.initials = getInitials(user.name);

	return user;
}
