import { Player } from ".";

import Chunk from "./chunk";
import chunkCache from "./chunk-cache";

export default class ChunkQueue {
	private queue = new Map<number, ArrayBuffer>();

	private index = -1;

	constructor(private readonly player: Player) {
		this.index = player.currentChunk;
	}

	next() {
		const next = this.queue.get(this.index);

		if (!next) {
			return null;
		}

		// Delete entry from queue.
		this.queue.delete(this.index);

		// Increment index.
		this.index++;

		return next;
	}

	enqueue(chunk: Chunk) {
		this.queue.set(chunk.getIndex(), chunk.getBuffer());

		this.player.emit("queue");
	}

	/**
	 * Clear
	 */
	clear() {
		this.queue.clear();
	}

	setIndex(index: number) {
		this.index = index;
	}

	get size() {
		return this.queue.size;
	}

	private async getChunk(index: number) {
		const cached = chunkCache.get(index);

		if (cached) {
			return new Chunk(cached, index);
		}

		const response = await fetch(
			this.player
				.getPlaybackInfo()
				.stream_url.replace("{chunk}", String(index))!,
		);
		const buffer = await response.arrayBuffer();

		return new Chunk(buffer, index);
	}

	async load(index: number) {
		const chunk = await this.getChunk(index);
		this.enqueue(chunk);
	}
}
