import { Playlist } from "@/types/playlist";
import { fetchAPI } from "./api";

const playlists = new Map<string, Playlist>();

export async function getPlaylist(playlistId: string): Promise<Playlist> {
	if (playlists.has(playlistId)) {
		return playlists.get(playlistId)!;
	}

	const playlist = await fetchAPI<Playlist>(`/playlists/${playlistId}`);

	playlists.set(playlistId, playlist);

	return playlist;
}

export async function getPlaylists(): Promise<Playlist[]> {
	return fetchAPI("/me/playlists");
}

export function parseDuration(seconds: string | number) {
	const hours = Math.floor(Number(seconds) / 3600);
	seconds = Number(seconds) % 3600;

	let minutes: string | number = Math.floor(seconds / 60);
	seconds = seconds % 60;

	let output = "";

	if (hours > 0) {
		output += `${hours}h `;
	}

	if (minutes > 0) {
		if (minutes < 10 && hours > 0) minutes = `0${minutes}`;

		output += `${minutes}m `;
	}

	if (seconds < 10) seconds = `0${seconds}`;

	output += `${seconds}s`;

	return output;
}
