import { A, useParams } from "@solidjs/router";
import { For, Show, createResource } from "solid-js";

import { getPlaylist, parseDuration } from "@/lib/playlists";
import NotFound from "../not-found";
import Track from "./track";

export default function Playlist() {
	const params = useParams<{ playlistId: string }>();
	const [playlist] = createResource(() => params.playlistId, getPlaylist);

	return (
		<Show when={playlist()} fallback={<NotFound />}>
			<section class="flex flex-col gap-12">
				<header class="flex items-center gap-8">
					<div class="size-56 rounded-xl border bg-tertiary" />
					<div class="flex flex-col gap-4 text-secondary">
						<h1 class="text-3xl font-bold text-primary">{playlist()?.name}</h1>
						<p>
							Created by{" "}
							<A
								href={`/users/${playlist()?.creator.id}`}
								class="text-primary hover:underline"
							>
								{playlist()?.creator.name}
							</A>
						</p>
						<p class="text-xs uppercase tracking-widest">
							{playlist()?.tracks_count} Track
							{playlist()?.tracks_count === 1 ? "" : "s"} –{" "}
							{parseDuration(playlist()?.duration ?? 0)}
						</p>
					</div>
				</header>

				<div aria-colcount={5}>
					<div class="playlist-row sticky -top-4 mb-2 border-b bg-secondary text-sm uppercase text-secondary">
						<span></span>
						<span>Title</span>
						<span>Album</span>
						<span class="hidden text-center md:block">Date added</span>
						<span class="text-center">Duration</span>
					</div>
					<For each={playlist()?.tracks} fallback={<EmptyPlaylist />}>
						{(track) => <Track track={track} />}
					</For>
				</div>
			</section>
		</Show>
	);
}

function EmptyPlaylist() {
	return (
		<div class="flex h-12 items-center justify-center text-center">
			😭 No tracks...
		</div>
	);
}
